@@ -1,7 +1,7 @@
 from flask_restful import Resource
 from flask import request
-from FastCNN.prx.GongDaProxy import predictSingle
-from FastCNN.prx.ValidProxy import predictPSingle2
+#from FastCNN.prx.GongDaProxy import predictSingle
+from FastCNN.prx.ValidProxy2 import predictPSingle2
 from FastCNN.prx.PathProxy import PathProxy
 
 class FastCNNApi(Resource):
@@ -23,14 +23,6 @@ class FastCNNApi(Resource):
         rtn['success'] = True
         return rtn
     
-    def getProjectTags():
-        rtn = {'success':False}
-        
-        data = PathProxy.getProjectTags("GongDa")
-        rtn['data'] = data
-        rtn['success'] = True
-        
-        return rtn
     
     def testPicture():
         rtn = {'success':False}
@@ -88,9 +80,6 @@ class FastCNNApi(Resource):
         if _cmd == "getProjectNames":
             return FastCNNApi.getProjectNames()
         
-        if _cmd == "getProjectTags":
-            return FastCNNApi.getProjectTags()
-        
         if _cmd == "testPicture":
             return FastCNNApi.testPicture()
         
